<md-select data-name="{{ widget.name }}"{% include "./attrs.html" -%}>
{%- for group_name, group_choices, group_index in widget.optgroups -%}
{%- if group_name -%}
<md-optgroup data-label="{{ group_name }}">
{%- endif -%}
{%- for widget in group_choices -%}
{%- include widget.template_name -%}
{%- endfor %}
{%- if group_name -%}
</md-optgroup>
{%- endif -%}
{%- endfor -%}
</md-select>
